@@ -47,7 +47,7 @@ void do_fourier_command(int gno, int setno, int ftype, int ltype);
 int do_compute(int gno, int setno, int graphto, int loadto, char *rarray, char *fstr);
 double trapint(double *x, double *y, double *resx, double *resy, int n);
 void do_digfilter(int set1, int set2);
-void do_linearc(int set1, int set2);
+void do_linearc(int gno1, int set1, int gno2, int set2);
 void do_xcor(int gno1, int set1, int gno2, int set2, int lag,  int covar);
 double do_int(int gno, int setno, int itype);
 void do_differ(int gno, int setno, int itype);
@@ -112,6 +112,8 @@ int seval(double *u, double *v, int ulen,
 void dft(double *jr, double *ji, int n, int iflag);
 void fft(double *real_data, double *imag_data, int n_pts, int nu, int inv);
 
+float humlik(const float x, const float y);
+
 void putparms(int gno, FILE * pp, int embed);
 void put_fitparms(FILE * pp, int embed);
 
@@ -124,6 +126,8 @@ void set_graph_line(int i, linetype *l);
 void set_graph_string(int i, plotstr *s);
 void set_graph_ellipse(int i, ellipsetype * e);
 
+char *object_types(int type);
+
 void pop_world(void);
 
 void define_autos(int aon, int au, int ap);
